HttpNetwork

Struct HttpNetwork 

pub struct HttpNetwork<C: RaftTypeConfig<NodeId = NodeId>> { /* private fields */ }
Network factory that creates HTTP connections to Raft peers.

Generic over the RaftTypeConfig so any application can use it.

Implementations

Source

impl<C: RaftTypeConfig<NodeId = NodeId>> HttpNetwork<C>

pub fn new() -> Self

Create a new network layer with default timeouts (5s RPC, 60s snapshot).

pub fn with_client(client: RaftHttpClient) -> Self

Create a new network layer with a custom client.

pub fn with_timeouts(rpc_timeout: Duration, snapshot_timeout: Duration) -> Self

Create a new network layer with custom timeouts.

pub fn with_timeouts_and_auth( rpc_timeout: Duration, snapshot_timeout: Duration, auth_token: Option<String>, ) -> Self

Create a new network layer with custom timeouts and an optional auth token.

pub async fn add_peer(&self, node_id: NodeId, address: String)

Add a peer address.

pub async fn remove_peer(&self, node_id: NodeId)

Remove a peer.

pub async fn peers(&self) -> HashMap<NodeId, String>

Get all known peers.