MemStateMachine

Struct MemStateMachine 

pub struct MemStateMachine<C, S, F>
where C: RaftTypeConfig<NodeId = NodeId>, S: Default + Clone + Serialize + DeserializeOwned + Send + Sync + 'static, F: Fn(&mut S, &C::D) -> C::R + Send + Sync + 'static,
{ /* private fields */ }
In-memory Raft state machine (v2 API).

Generic over:

  • C: openraft RaftTypeConfig
  • S: application state type
  • F: a function fn(&mut S, &C::D) -> C::R that applies a log entry to the state.

The apply_fn approach keeps the state machine generic: the application provides a closure that knows how to mutate S given a log entry payload of type C::D.

Implementations

Source

impl<C, S, F> MemStateMachine<C, S, F>
where C: RaftTypeConfig<NodeId = NodeId>, S: Default + Clone + Serialize + DeserializeOwned + Send + Sync + 'static, F: Fn(&mut S, &C::D) -> C::R + Send + Sync + 'static,

pub fn new(apply_fn: F) -> Self

Create a new state machine with the given apply function.

pub fn data(&self) -> Arc<RwLock<SmData<C, S>>>

Get a read handle to the inner state machine data (for reading application state).