Module types

Module types 

Core type aliases and re-exports for the consensus layer.

Structs

BasicNode
An implementation of trait Node that contains minimal node information.

Type Aliases

NodeId
Raft node identifier. Every node in a cluster must have a unique NodeId.