pub struct HttpNetwork<C: RaftTypeConfig<NodeId = NodeId>> { /* private fields */ }Expand description
Network factory that creates HTTP connections to Raft peers.
Generic over the RaftTypeConfig so any application can use it.
Implementations
Sourceimpl<C: RaftTypeConfig<NodeId = NodeId>> HttpNetwork<C>
impl<C: RaftTypeConfig<NodeId = NodeId>> HttpNetwork<C>
Sourcepub fn with_client(client: RaftHttpClient) -> Self
pub fn with_client(client: RaftHttpClient) -> Self
Create a new network layer with a custom client.
Sourcepub fn with_timeouts(rpc_timeout: Duration, snapshot_timeout: Duration) -> Self
pub fn with_timeouts(rpc_timeout: Duration, snapshot_timeout: Duration) -> Self
Create a new network layer with custom timeouts.
Sourcepub fn with_timeouts_and_auth(
rpc_timeout: Duration,
snapshot_timeout: Duration,
auth_token: Option<String>,
) -> Self
pub fn with_timeouts_and_auth( rpc_timeout: Duration, snapshot_timeout: Duration, auth_token: Option<String>, ) -> Self
Create a new network layer with custom timeouts and an optional auth token.
Sourcepub async fn remove_peer(&self, node_id: NodeId)
pub async fn remove_peer(&self, node_id: NodeId)
Remove a peer.